// Different classes used to transfer access and change variables across components

class userData {
    constructor(){
        this.data = Vue.reactive({
            user_id: 0,
            username: '',
            role: false,
        })
    }
}

class pingData {
    constructor(){
        this.data = Vue.reactive({
            success: false,
            danger: false,
            message: "",
            alert: "",
        })
    }
}

class itemData {
    constructor(){
        this.data = Vue.reactive({
            item_id: 0,
            img_name: "",
            title: "",
            description: "",
            alert: "",
            price: 0,
            discount: 0,
            is_item: 0,
            duration: 0,
        })
    }
}

class productData {
    constructor(){
        this.data = Vue.reactive({
            items: {},
            sum_time: 0,
            sum_value: 0,
            success: false,
            danger: false
        })
    }
}

class usersData {
    constructor(){
        this.data = Vue.reactive({
            users: {},

        })
    }
}

class categoryData {
    constructor(){
        this.data = Vue.reactive({
            categories: {}
        })
    }
}

class cardsData {
    constructor(){
        this.data = Vue.reactive({
            cards: {}
        })
    }
}

//All contact information with options to change platforms name, link and logos from within the settings menu
class contactInformation{
    constructor(){
        this.data = Vue.reactive({
            name: "",
            email: "",
            phone: "",
            address: "",
            address_link: "",
            platform_1: "",
            platform_1_url: "",
            platform_1_logo: "",
            platform_2: "",
            platform_2_url: "",
            platform_2_logo: "",
            platform_3: "",
            platform_3_url: "",
            platform_3_logo: "",
            platform_4: "",
            platform_4_url: "",
            platform_4_logo: "",
            comment: "",
        })
    }
}

class checkoutInformation{
    constructor(){
        this.data = Vue.reactive({
            checkout_message: "",
            shipping_available: false,
            shipping_message: "",
            shipping_price: 0,
        })
    }
}

// Color palette divided by 20+ colors that is fully customizable in the settings menu that makes it possible to change
// the appearance of the full website
class colorData {
    constructor(){
        this.data = Vue.reactive({
            header: "#F9F9F9",
            inner_header: "#FFFFFF",
            body: "#FFFFFF",
            inner_body: "#FFFFFF",
            footer: "#EDEDED",
            inner_footer: "#F7F7F7",
            title: "#000000",
            description: "#6c757d",
            settings_list: "#FFFFFF",
            settings_text: "#0000EE",
            cart_button: "#F7F7F7",
            cart_button_text: "#000000",
            button_accept: "#0275d8",
            button_accept_text: "#FFFFFF",
            button_cancel: "#adb5bd",
            button_cancel_text: "#FFFFFF",
            success: "#20c997",
            success_text: "#FFFFFF",
            danger: "#d9534f",
            danger_button_text: "#FFFFFF",
            danger_text: "#d9534f",
            link_text: "#0000EE",
        })
    }
}

const user = new userData();
const product = new productData();
const categories = new categoryData();
const cart = new productData();
const users = new usersData();
const contact = new contactInformation();
const cards = new cardsData();
const checkout_info = new checkoutInformation();
const color = new colorData(); //Color palette on website, overwritten from database
const ping = new pingData();
const item_data = new itemData();


// function setCookie(name,value) {
//     document.cookie = name + '=' + (value || "")
// }


// Sends mail
async function sendMail(title, body, receiver) {
    await fetch("/send_mail", {
        method: 'POST',
        headers: {"Content-Type": "application/json"},
        body: JSON.stringify({
            'title': title,
            'body': body,
            'receiver': receiver,
        })
    })
}


// Retrieves the different users username and role
async function getUsers()  {
    let request = await fetch("/users",{
        method: 'GET',
    });
    if (request.status === 200) {
        users.data.users = await request.json();
    }
}

// Function that when called will display the message in a "Success" or "Danger" colored background for 2 seconds
function showMessage(message, state=true) {
        ping.data.success = state;
        ping.data.danger = !state;
        ping.data.message = message;
        resetTimer(ping.data.alert);
        ping.data.alert = setTimeout(function() {
            ping.data.success = false;
            ping.data.danger = false;
        }, 2000);
    }

    // Resets the timer of the alert to make alert timers overlap instead of ending on the same timer
function resetTimer(alert){
    clearTimeout(alert)
}

// Retrieves the user information of the current user logged in
async function getUsername()  {
    let request = await fetch("/user",
        {method: 'GET',});
    if (request.status === 200) {
        let user_data = await request.json();
        user.data.username = user_data['username'];
        user.data.role = user_data['role'];
        user.data.user_id = user_data['userid'];
    }
}

// Retrieves att products stored on the database
async function getProducts() {
    let request = await fetch("/products", {
        method: 'GET',
    });
    if (request.status === 200){
        product.data.items = await request.json();
        }

}

// Retrieves the messages and information displayed on checkout
async function getCheckoutInfo() {
    let request = await fetch("/checkout", {
        method: 'GET',
    });
    if (request.status === 200){
        checkout_info.data = await request.json();
        }
}

// Retrieves the categories used by the different products
async function getCategories() {
    let request = await fetch("/categories", {
        method: 'GET',
    });
        if (request.status === 200){
            categories.data.categories = await request.json();
            categories.data.categories = categories.data.categories.categories.sort();
            }
}

// Retrieves gift card and discount cards from the database
async function getCards() {
    let request = await fetch("/gift_cards", {
        method: 'GET',
    });
        if (request.status === 200){
            cards.data.cards = await request.json();
            }
}

// Converts the cart-cookie to a dictionary that contains item name and quantity
async function getCart() {
    let cart_items = {};
        let items = getItemsFromCookie('cart');
        if (items) {
            for (const [key, value] of Object.entries(items)) {
                if ((key in product.data.items)) {
                    cart_items[key] = {
                        'name': product.data.items[key]['product_name'], 'quantity': value,
                        'is_item': product.data.items[key]['is_item'], 'duration': product.data.items[key]['duration'],
                        'price': product.data.items[key]['price'], 'discount': product.data.items[key]['discount'],
                        'category': product.data.items[key]['category']
                    };
                }
            }
        }
        cart.data.items = cart_items;
    getCartTotal();
}
function getCartTotal() {
    let products_calculated = [];
    cart.data['sum_value'] = 0;
    cart.data['sum_time'] = 0;
    for (const [key, item] of Object.entries(cart.data.items)) {
        let product_name = cart.data.items[key]['name'];
            if (!products_calculated.includes(product_name)){ // Items get counted multiple times while services only get counted once
                if (item['is_item']){
                    cart.data['sum_value'] += Math.round(item['price']*item['quantity']*(1-(item['discount']/100)));
                } else {
                    cart.data['sum_value'] += Math.round(item['price']*(1-(item['discount']/100)));
                    cart.data['sum_time'] += item['duration'];
                }
                products_calculated.push(product_name)
            }
        }
}

//Loads color palette used on the page from a json file
async function loadColors(){
    let request = await fetch("/colors", {
        method: 'GET',
    });
        if (request.status === 200){
            color.data = await request.json();
            }
}

// Retrieves contact information
async function getContact(){
    let request = await fetch("/contact", {
        method: 'GET',
    });
        if (request.status === 200){
            contact.data = await request.json();
            }
}

// Updated gift card value on a specified card
// First it retrieved the card from the database based on its id, changes its value and sores it
async function updateGiftCardValue(card_id, value) {
    let request = await fetch("/gift_cards", {
        method: 'GET',
    });
    let response = await request.json();
    response = response[card_id];
    request = await fetch("/gift_cards", {
        method: 'PUT',
        headers: {"Content-Type": "application/json"},
        body: JSON.stringify({
            'card_id': response["card_id"],
            'card_code': response["card_code"],
            'card_type': response["card_type"],
            'discount_type': response["discount_type"],
            'category': response["card_category"],
            'discount': response["card_discount"],
            'value': value,
            'expiration': response["expiration_date"],
        })
    })
}

// !taken from stackoverflow! Used the be able to read the content of a set cookie
function readCookie(name) {
    	let key = name + "=";
    	let cookies = document.cookie.split(';');
    	for (let i = 0; i < cookies.length; i++) {
    		let cookie = cookies[i];
    		while (cookie.charAt(0) === ' ') {
                cookie = cookie.substring(1, cookie.length);
            }
    		if (cookie.indexOf(key) === 0) {
                return cookie.substring(key.length, cookie.length);
            }
    	}
    	return null;
    }

// Appends a value to a given cookie
// Cookie contains values of item_id such as "1 2 2 3" means 1x item with id = 1, 2x of item with id = 2 and
// 1x of item with id = 3
function appendToCookie(name, value) {
    let cookie = readCookie(name);
    if (checkItemLimit(value,5)) {
        if (cookie) {
            document.cookie = name + "=" + cookie + " " + value
        } else {
            document.cookie = name + "=" + value
        }
    }
}

//Retrieves the cookie and makes an array of it
function getItemsFromCookie(name) {
    let cart = {};
    let cookie = readCookie(name);
    if (cookie) {
        let items = cookie.split(" ");
        for (let i = 0; i < items.length; i++) {
            if (cart[items[i]]) {
                cart[items[i]] += 1
            } else {
                cart[items[i]] = 1
            }
        }
        return cart
    }
    return cart
}

//Returns array of integers from cart
function getCartArray() {
    let array = [];
    let cookie = readCookie('cart');
    if (cookie) {
        let split_cookie = cookie.split(" ");
        for (let i = 0; i < split_cookie.length; i++) {
            if (split_cookie[i]) {
                array.push(parseInt(split_cookie[i]));
            }
        }
        return array;

    }
    return array
}

// Updates cookie with new set quantity information
async function changeQuantity(quantity, item) {
    let cookie = getCartArray();
    let newCookie = "";
    for (let i = 0; i < cookie.length; i++) {
        if (cookie[i] !== parseInt(item)) {
            newCookie += cookie[i] + " ";
        }
    }
    for (let i = 0; i < quantity; i++) {
        newCookie += item + " ";
    }
    document.cookie = 'cart=' + newCookie;
}

//Edits the cart cookie to get rid of a item (item id) in the string
function removeItem(item_id) {
    let cookie = getCartArray();
    let newCookie = "";
    for (let i = 0; i < cookie.length; i++) {
        if (cookie[i] !== parseInt(item_id)) {
            newCookie += cookie[i] + " ";
        }
    }
    document.cookie = 'cart=' + newCookie
}

function clearCart() {
    document.cookie = 'cart=' + ""
}

//Finds number of the same item in the cart array
function checkItemLimit(item_id, limit) {
    let cart = getCartArray();
    return cart.filter(x => x === item_id).length < limit;
}

function isUser() {
    return user.data.user_id;
}



// Dictionary used to organize the settings menu and navigation
// id: the ID of the modal, what tag needed to trigger it to show
// header: what title that is being showed in the header of the modal
// logo: a bootstrap icon name that will display a certain icon in the top right corner
// return: decides where to go when the icon in the corner is clicked

const settings_menu = {
    'settings': {
        'id': 'settingsModal',
        'header': 'Settings',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'userModal',
    },
    'user': {
        'id': 'userModal',
        'header': 'User',
        'logo': 'bi bi-x-circle',
        'return': false,
    },
    'cart': {
        'id': 'cartModal',
        'header': 'Cart',
        'logo': 'bi bi-x-circle',
        'return': false
    },
    'item': {
        'id': 'itemModal',
        'header': 'Product',
        'logo': 'bi bi-x-circle',
        'return': false
        },
    'login': {
        'id': 'loginModal',
        'header': 'Login',
        'logo': 'bi bi-x-circle',
        'return': false
        },
    'orders': {
        'id': 'ordersModal',
        'header': 'Orders',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'userModal'
        },
    'editProducts': {
        'id': 'editProductsModal',
        'header': 'Products',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'settingsModal'
        },
    'editUsers': {
        'id': 'editUsersModal',
        'header': 'Users',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'settingsModal'
        },
    'editAppearance': {
        'id': 'editAppearanceModal',
        'header': 'Appearance',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'settingsModal'
        },
    'editDiscounts': {
        'id': 'editDiscountsModal',
        'header': 'Discounts',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'settingsModal'
        },
    'addProduct': {
        'id': 'addProductModal',
        'header': 'Add new product',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editProductsModal'
        },
    'editProduct': {
        'id': 'editProductModal',
        'header': 'Edit product',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editProductsModal'
        },
    'removeProduct': {
        'id': 'removeProductModal',
        'header': 'Remove product',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editProductsModal'
        },
    'addUser': {
        'id': 'addUserModal',
        'header': 'Add new user',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editUsersModal'
        },
    'editUser': {
        'id': 'editUserModal',
        'header': 'Edit user',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editUsersModal'
        },
    'removeUser': {
        'id': 'removeUserModal',
        'header': 'Remove user',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editUsersModal'
        },
    'addDiscount': {
        'id': 'addDiscountModal',
        'header': 'Create gift card',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editDiscountsModal'
        },
    'addSale': {
        'id': 'addSaleModal',
        'header': 'Begin a sale',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editDiscountsModal'
        },
    'updateDiscount': {
        'id': 'updateDiscountModal',
        'header': 'Update discount code',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editDiscountsModal'
        },
    'removeCodes': {
        'id': 'removeCodesModal',
        'header': 'Remove discount code',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editDiscountsModal'
        },
    'updateCheckout': {
        'id': 'updateCheckoutModal',
        'header': 'Update checkout information',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editAppearanceModal'
        },
    'updateHeader': {
        'id': 'updateHeaderModal',
        'header': 'Update header logo',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editAppearanceModal'
        },
    'updateBanner': {
        'id': 'updateBannerModal',
        'header': 'Update banner',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editAppearanceModal'
        },
    'updateInfo': {
        'id': 'updateInfoModal',
        'header': 'Update contact info',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editAppearanceModal'
        },
    'updatePalette': {
        'id': 'updatePaletteModal',
        'header': 'Customize color palette',
        'logo': 'bi bi-arrow-left-circle',
        'return': 'editAppearanceModal'
        },
};