const updateBannerC = {
    props: [],
    template: `
<div id="uploadBanner" class="" v-if="!banner_selected">
<form method = "POST" enctype = "multipart/form-data">
    <div class="custom-file form-group">
        <label class="form-label" for="customFile" :style="{ color: [colors.description]}">Image</label>
        <input type="file" class="form-control" id="bannerFile" name="file" @change="onFileChange" />
        <p :style="{ color: [colors.danger_text]}" v-if="image_danger && !image">Image is required</p>
        <small class="form-text text-muted" :style="{ color: [colors.description]}">Max: 350x900</small>
    </div>
</form>
<div class="navbar-brand col-auto">
        <a style="max-height: 50px; max-width: 300px" href="/"><img :src="image" style="max-height: 50px; max-width: 300px"></a>
</div>
<div class="modal-footer">
    <button type="button" class="btn" @click="upload()" :style="{ background: [colors.button_accept], color: [colors.button_accept_text]}">Upload</button>
</div>
</div>

<div id="selectBanner" v-if="!banner_selected">
<h4 :style="{ color: [colors.title]}">Remove banner</h4>
    <ul class="list-group">
    <label class="list-group-item" v-for="(banner, index) in banners" :style="{ background: [colors.settings_list]}">
        <a href="#" class="nav-link" @click="getBannerData(banner)" :style="{ color: [colors.settings_text]}">
          {{ 'Banner '+(index+1) }}
        </a>
    </label>
    </ul>
</div>

<div id="thisBanner" v-if="banner_selected">
    <div>
        <img class="d-flex justify-content-between mx-auto" :src="'/static/images/headers/'+banner_image" style="max-width: 90%; max-height: 30%">
    </div>
</div>

<div class="modal-footer" v-if="banner_selected">
    <button type="button" class="btn" @click="onReturn()" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Back</button>
    <button type="button" class="btn" :style="{ background: [colors.danger], color: [colors.danger_button_text]}" @click="deletes()">Delete</button>
</div>



    `,
    data: function () {
        return {
            colors: color.data,
            banner_selected: false,
            banners: [],
            banner_image: "",
            banner: {},
            image: "",
            image_danger: false,
        }
    },
    created: async function() {
        await loadColors();
        await this.getBanners();
        this.colors = color.data;
    },
    methods: {
        // !Taken from stack! Upload file as a Base64 string
        onFileChange(e) {
              var files = e.target.files || e.dataTransfer.files;
              if (!files.length)
                return;
              this.createImage(files[0]);
            },
            createImage(file) {
              let image = new Image();
              let reader = new FileReader();
              let vm = this;

              reader.onload = (e) => {
                vm.image = e.target.result;
              };
              reader.readAsDataURL(file);
            },
        // Get banners already on server
        getBanners: async function() {
            let request = await fetch("/banner", {
                method: 'GET',
            });
            if (request.status === 200) {
                this.banners = await request.json();
            }
        },
        // Upload the new banner
        upload: async function () {
            if (this.image && isUser()) {
                let request = await fetch("/banner", {
                    method: 'POST',
                    headers: {"Content-Type": "application/json"},
                    body: JSON.stringify({
                        'img': this.image
                    })
                });
                if (request.status === 200) {
                    await this.getBanners();
                    this.onReturn();
                    this.image_danger = false;
                    showMessage("Banner uploaded")
                }
            } else {
                this.image_danger = true
            }
        },
        onReturn() {
            this.banner_selected = false;
            this.banner_image = "";
            this.image = "";
            this.image_danger = false;
        },
        getBannerData(banner){
            this.banner_selected = true;
            this.banner_image = banner;
        },
        // Delete a banner from database
        deletes: async function () {
            if (isUser()) {
                let request = await fetch("/banner/"+this.banner_image, {
                    method: 'DELETE',
                });
                if (request.status === 200) {
                    await this.getBanners();
                    this.onReturn();
                    showMessage("Banner deleted!");
                }
            }
        },
    },
};