const addDiscountC = {
    props: [],
    template: `
<div id="addProduct" class="">
    <div id="select_type" v-if="!selected">
        <ul class="list-group">
        <label class="list-group-item" :style="{ background: [colors.settings_list]}" >
            <a href="#" class="nav-link" @click="selectType('gift_card')" :style="{color: [colors.settings_text]}">
              Gift card
            </a>
        </label>
        <label class="list-group-item" :style="{ background: [colors.settings_list]}" >
            <a href="#" class="nav-link" @click="selectType('discount_code')" :style="{color: [colors.settings_text]}">
              Discount code
            </a>
        </label>
        </ul>
    </div>
    <div id="addProduct" v-if="selected">
        <form method = "POST" enctype = "multipart/form-data">
            <div class="form-group">
                <label :style="{ color: [colors.description]}">Card code</label>
                <div class="row m-0">
                    <input class="form-control m-0 col-9" v-model="card_code" placeholder="Enter card code">
                    <a class="col-1 mx-1 p-0">
                        <div class="btn" @click="generateCode(16)" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Generate</div>
                    </a>
                </div>
                <p :style="{ color: [colors.danger_text]}" v-if="code_danger && !card_code">Code is required</p>
            </div>
            <div class="form-group" v-if="selected == 'discount_code'">
                <label :style="{ color: [colors.description]}">Discount type</label>
                <select class="form-control m-0 col-9" v-model="discount_type">
                    <option value="all">All</option>
                    <option value="service">Service</option>
                    <option value="items">Items</option>
                </select>
            </div>
            <div class="form-group" v-if="selected == 'discount_code'">
                <label :style="{ color: [colors.description]}">Category</label>
                <select class="form-control m-0 col-9" v-model="category" >
                    <option value="all">All</option>
                    <option v-for="(option, index) in categories" :value="option">{{option}}</option>
                </select>
            </div>
            <div class="form-group" v-if="selected == 'discount_code'">
                <label :style="{ color: [colors.description]}">Discount</label>
                <input class="form-control m-0 col-9" v-model="discount" type="number" placeholder="Enter discount" @change="checkDiscount()">
                <p :style="{ color: [colors.danger_text]}" v-if="discount_danger && !discount">Discount is required</p>
            </div>
            <div class="form-group" v-if="selected == 'gift_card'">
                <label :style="{ color: [colors.description]}">Value</label>
                <input class="form-control m-0 col-9" v-model="value" type="number" placeholder="Enter value" @change="checkValue()">
                <p :style="{ color: [colors.danger_text]}" v-if="value_danger && !value">Value is required</p>
            </div>
            <div class="form-group">
                <label :style="{ color: [colors.description]}">Expiration</label>
                <input class="form-control m-0 col-9" v-model="expiration" type="date">
            </div>
        </form>
        <div class="modal-footer">
            <button type="button" class="btn" @click="onReturn()" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Back</button>
            <button type="button" class="btn" @click="upload()" :style="{ background: [colors.button_accept], color: [colors.button_accept_text]}">Save</button>
        </div>
    </div>
</div>

    `,
data: function(){
        return {
            colors: color.data,
            selected: "",
            card_code: "",
            discount_type: "all",
            category: "all",
            discount: 0,
            value: 0,
            expiration: null,
            code_danger: false,
            discount_danger: false,
            value_danger: false,

        }
    },
created: async function(){
    await loadColors();
    this.colors = color.data;
},
    methods:{
        selectType(type){
            this.selected = type;
        },
        onReturn(){
            this.selected = "";
            this.card_code = "";
            this.discount_type = "all";
            this.category = "all";
            this.discount = 0;
            this.value = 0;
            this.expiration = null;
            this.value_danger = false;
            this.discount_danger = false;
            this.code_danger = false;
        },
        // Limits discount to min 0 and max 100
        checkDiscount(){
            if (this.discount < 0 || Number.isInteger(this.discount)) {
                this.discount = 0;
            } else if (this.discount > 100) {
                this.discount = 100;
            }
        },
        // Limits gift_card to min 0 and max 3000
        checkValue(){
            if (this.value < 0 || Number.isInteger(this.value)) {
                this.value = 0;
            } else if (this.value > 3000) {
                this.value = 3000;
            }
        },
        // https://stackoverflow.com/questions/1349404/generate-random-string-characters-in-javascript
        generateCode(length){
            let result           = [];
            let characters       = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
            let charactersLength = characters.length;
            for ( var i = 0; i < length; i++ ) {
              result.push(characters.charAt(Math.floor(Math.random() *
         charactersLength)));
           }
           this.card_code = result.join('');
        },
        // Adds gift card or discount code to database
        upload: async function(){
            if (this.card_code && ((this.selected === 'gift_card' && this.value > 0) || (this.selected === 'discount_code' && this.discount > 0)) && isUser()) {
                let request = await fetch("/gift_card", {
                    method: 'POST',
                    headers: {"Content-Type": "application/json"},
                    body: JSON.stringify({
                        'card_code': this.card_code, 'card_type': this.selected, 'discount_type': this.discount_type, 'category': this.category,
                        'discount': this.discount, 'value': this.value, 'expiration': this.expiration,
                    })
                });
                if (request.status === 200) {
                    this.onReturn();
                    showMessage("Promo code created!");
                    $('#addDiscountModal').modal('hide');
                    $('#editDiscountsModal').modal('show');
                }
            } else {
                if (this.value <= 0) {
                    this.value_danger = true;
                }
                if (this.discount <= 0) {
                    this.discount_danger = true;
                }
                if (!this.card_code) {
                    this.code_danger = true;
                }
            }
        },

    },
    computed: {
        categories: function(){
            return categories.data.categories.sort()
        }
    }

};