const addSaleC = {
    props: [],
    template: `
<div v-if="!product_selected">
    <ul class="list-group">
    <label class="list-group-item" v-for="product in products.items" :style="{ background: [colors.settings_list]}" >
        <a href="#" class="nav-link" @click="getItemData(product.product_id)" :style="{color: [colors.settings_text]}">
          {{ product.product_name }}
        </a>
    </label>
    </ul>
</div>
<div id="editProduct" v-if="product_selected">
<form method = "POST" enctype = "multipart/form-data">
    <div class="form-group">
        <label :style="{ color: [colors.description]}">Title</label>
        <h4 :style="{ color: [colors.title]}">{{title}}</h4>
    </div>
    <div class="form-group">
        <label :style="{ color: [colors.description]}">Discount</label>
        <input class="form-control m-0 col-4" v-model="discount" type="number" placeholder="Enter discount" @change="updatePrice(); this.checkDiscount();">
    </div>
</form>

    <div class="col p-2 border-3" :style="{ background: [colors.body] }">
        <div class="row my-5">
              <div class="col-md-9 mb-4 mx-auto">
                <div class="card h-100" :style="{ background: [colors.body]}">
                  <a v-if="image" href="#"><img class="card-img-top" :src="image" style="max-height: 500px; max-width: 400px" alt=""></a>
                  <a v-else href="#"><img class="card-img-top" :src="'/static/images/products/'+old_image+'.jpg'" style="max-height: 500px; max-width: 400px" alt=""></a>
                  <div class="card-body" :style="{ background: [colors.main_card_color]}">
                    <h4 class="card-title text-dark">
                      <a href="#" :style="{ color: [colors.title]}">{{ title }}</a>
                    </h4>
                    <p v-if="description.length<50" class="card-text" :style="{ color: [colors.description]}">{{ description }}</p>
                    <p v-else class="card-text" :style="{ color: [colors.description]}">{{ description.substring(0,50)+'..' }}</p>
                    <p class="d-flex justify-content-end" v-if="!item" :style="{ color: [colors.description]}"><small>Tid: {{ duration }}min</small></p>
                </div>
                  <div class="card-footer d-flex justify-content-between" :style="{ background: [colors.inner_footer_color]}">
                    <div class="d-flex">
                    <p v-if="!discount" class="my-auto mx-2" :style="{ color: [colors.title]}">kr{{ price }},-</p>
                    <p v-if="discount" class="my-auto mx-2" :style="{ color: [colors.description]}"><del>kr{{ price }},-</del></p>
                    <p v-if="discount" class="my-auto mx-2" :style="{ color: [colors.title]}">kr{{ new_price }},-</p>
                    </div>
                    <button type="button" class="btn nav-link" :style="{ background: [colors.cart_button], color: [colors.cart_button_text]}" >
                            Add to cart
                    </button>
                  </div>
              </div>
            </div>
        </div>
</div>
<div class="modal-footer">
    <button type="button" class="btn" @click="onReturn()" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Cancel</button>
    <button type="button" class="btn" @click="uploadEdit()" data-bs-dismiss="modal" :style="{ background: [colors.button_accept], color: [colors.button_accept_text]}">Save</button>
</div>
</div>
<!--<img :src="image" />-->

    `,
    data: function () {
        return {
            colors: color.data,
            products: product.data,
            product_selected: false,
            id: 0,
            title: "",
            description: "",
            price: 0,
            new_price: 0,
            duration: 0,
            category: "",
            item: 0,
            discount: 0,
            image: "",
            old_image: "",
            final_image: "",
        }
    },
    created: async function() {
        await loadColors();
        this.colors = color.data;
    },
    methods: {
        getItemData: async function(product_id) {
            let request = await fetch("/product/id/"+product_id, {
                method: 'GET',
            });
            if (request.status === 200) {
                let response = await request.json();
                this.id = response['product_id'];
                this.title = response['product_name'];
                this.description = response['product_description'];
                this.price = response['price'];
                this.duration = response['duration'];
                this.category = response['category'];
                this.item = response['is_item'];
                this.discount = response['discount'];
                this.old_image = response['img_name'];
                this.final_image = response['img_name'];
                this.product_selected = true;
                this.updatePrice();
            }
        },
        checkDiscount(){
            if (this.discount <= 0 || Number.isInteger(this.discount)) {
                this.discount = 0;
            } else if (this.discount > 100) {
                this.discount = 100;
            }
        },
        onReturn() {
            this.product_selected = false;
            this.id = 0;
            this.title = "";
            this.description = "";
            this.price = 0;
            this.duration = 0;
            this.item = 0;
            this.image = "";
            this.old_image = "";
            this.final_image = "";
        },
        // Update the changed discount on the product in the database
        uploadEdit: async function () {
            if (this.image) {
                this.final_image = this.image
            }
            if ((this.image || this.old_image) && isUser()) {
                let request = await fetch("/product", {
                    method: 'PUT',
                    headers: {"Content-Type": "application/json"},
                    body: JSON.stringify({ 'id': this.id,
                        'title': this.title, 'description': this.description, 'price': this.price,
                        'duration': this.duration, 'item': this.item, 'img': this.final_image,
                        'old_img': this.old_image, 'discount': this.discount, 'category': this.category
                    })
                });
                if (request.status === 200) {
                    await getProducts();
                    this.onReturn();
                    showMessage("Product discount is updated!");
                    $('#addSaleModal').modal('hide');
                    $('#editDiscountsModal').modal('show');
                }
            }
        },
        updatePrice(){
            this.new_price = Math.round(this.price*(1-(this.discount/100)));
        },
    },
    computed: {
        categories: function(){
            return categories.data.categories.sort();
        }
    }
};