const updateDiscountC = {
    props: [],
    template: `
<div id="selectCards" v-if="!selected && !cur_card">
    <ul class="list-group" @click="sortCards()">
    <label class="list-group-item" :style="{ background: [colors.settings_list]}" >
        <a href="#" class="nav-link" @click="select('gift_cards')" :style="{color: [colors.settings_text]}">
          Gift cards
        </a>
    </label>
    <label class="list-group-item" :style="{ background: [colors.settings_list]}" >
        <a href="#" class="nav-link" @click="select('discount_codes')" :style="{color: [colors.settings_text]}">
          Discount codes
        </a>
    </label>
    </ul>
</div>
<div v-if="selected == 'gift_cards' && !cur_card">
    <ul class="list-group">
    <label class="list-group-item" v-for="card in gift_cards" :style="{ background: [colors.settings_list]}" >
        <a href="#" class="nav-link" :style="{color: [colors.settings_text]}" @click="getCard(card.card_id)">
          {{ card.card_code }}
        </a>
    </label>
    </ul>
</div>
<div v-if="selected == 'discount_codes' && !cur_card">
    <ul class="list-group">
    <label class="list-group-item" v-for="card in discount_codes" :style="{ background: [colors.settings_list]}" >
        <a href="#" class="nav-link" :style="{color: [colors.settings_text]}" @click="getCard(card.card_id)">
          {{ card.card_code }}
        </a>
    </label>
    </ul>
</div>
<div id="addProduct" v-if="selected && cur_card">
        <form method = "POST" enctype = "multipart/form-data">
            <div class="form-group">
                <label :style="{ color: [colors.description]}">Card code</label>
                <div class="row m-0">
                    <input class="form-control m-0 col-9" v-model="card_code" placeholder="Enter card code">
                    <a class="col-1 mx-1 p-0">
                        <div class="btn" @click="generateCode(16)" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Generate</div>
                    </a>
                </div>
                <p :style="{ color: [colors.danger_text]}" v-if="code_danger && !card_code">Code is required</p>
            </div>
            <div class="form-group" v-if="card_type == 'discount_code'">
                <label :style="{ color: [colors.description]}">Discount type</label>
                <select class="form-control m-0 col-9" v-model="discount_type">
                    <option value="all">All</option>
                    <option value="service">Service</option>
                    <option value="items">Items</option>
                </select>
            </div>
            <div class="form-group" v-if="card_type == 'discount_code'">
                <label :style="{ color: [colors.description]}">Category</label>
                <select class="form-control m-0 col-9" v-model="category">
                    <option value="all">All</option>
                    <option v-for="(option, index) in categories" :value="option">{{option}}</option>
                </select>
            </div>
            <div class="form-group" v-if="card_type == 'discount_code'">
                <label :style="{ color: [colors.description]}">Discount</label>
                <input class="form-control m-0 col-9" v-model="discount" type="number" placeholder="Enter discount" @change="checkDiscount()">
                <p :style="{ color: [colors.danger_text]}" v-if="discount_danger && !discount">Discount is required</p>
            </div>
            <div class="form-group" v-if="card_type == 'gift_card'">
                <label :style="{ color: [colors.description]}">Value</label>
                <input class="form-control m-0 col-9" v-model="value" type="number" placeholder="Enter value" @change="checkValue()">
                <p :style="{ color: [colors.danger_text]}" v-if="value_danger && !value">Value is required</p>
            </div>
            <div class="form-group">
                <label :style="{ color: [colors.description]}">Expiration</label>
                <input class="form-control m-0 col-9" v-model="expiration" type="date">
            </div>
        </form>
    </div>
<div class="modal-footer" v-if="selected">
    <button type="button" class="btn" @click="onReturn()" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Cancel</button>
    <button v-if="cur_card" type="button" class="btn" @click="uploadChange()"  :style="{ background: [colors.button_accept], color: [colors.button_accept_text]}">Save</button>
</div>
    `,
data: function(){
        return {
            selected: "",
            colors: color.data,
            gift_cards: [],
            discount_codes: [],
            cur_card: null,
            card_id: 0,
            card_code: "",
            card_type: "",
            discount_type: "all",
            category: "all",
            discount: 0,
            value: 0,
            expiration: null,
            code_danger: false,
            discount_danger: false,
            value_danger: false,
        }
    },
created: async function(){
        await loadColors();
        this.colors = color.data;
        },

methods: {
        sortCards(){
            if (this.gift_cards.length === 0 && this.discount_codes.length === 0) {
                for (const [key, card] of Object.entries(this.cards)) {
                    if (card.card_type === 'gift_card') {
                        this.gift_cards.push(card)
                    } else {
                        this.discount_codes.push(card)
                    }
                }
            }
            },
    select(option){
            this.selected = option;
    },
    // Retrieve selected card
    getCard: async function(card_id){
                let request = await fetch("/gift_card/id/"+card_id, {
                method: 'GET',
                });
                if (request.status === 200) {
                    let response = await request.json();
                    this.cur_card = response[card_id];
                    this.getCardData();
                }
    },
    getCardData(){
            this.card_code = this.cur_card['card_code'];
            this.category = this.cur_card['card_category'];
            this.discount = this.cur_card['card_discount'];
            this.value = this.cur_card['card_value'];
            this.expiration = this.cur_card['expiration_date'];
            this.discount_type = this.cur_card['discount_type'];
            this.card_type = this.cur_card['card_type'];
            this.card_id = this.cur_card['card_id'];
    },
    checkDiscount(){
            if (this.discount < 0 || Number.isInteger(this.discount)) {
                this.discount = 0;
            } else if (this.discount > 100) {
                this.discount = 100;
            }
        },
        checkValue(){
            if (this.value < 0 || Number.isInteger(this.value)) {
                this.value = 0;
            } else if (this.value > 3000) {
                this.value = 3000;
            }
        },
    // https://stackoverflow.com/questions/1349404/generate-random-string-characters-in-javascript
    generateCode(length){
        let result           = [];
        let characters       = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
        let charactersLength = characters.length;
        for ( var i = 0; i < length; i++ ) {
          result.push(characters.charAt(Math.floor(Math.random() *
     charactersLength)));
       }
       this.card_code = result.join('');
    },
    // Update changes to gift card
    uploadChange: async function() {
        if (this.card_code && ((this.selected === 'gift_cards' && this.value > 0) || (this.selected === 'discount_codes' && this.discount > 0)) && isUser()) {
            let request = await fetch("/gift_cards", {
                method: 'PUT',
                headers: {"Content-Type": "application/json"},
                body: JSON.stringify({
                    'card_code': this.card_code,
                    'card_type': this.card_type,
                    'discount_type': this.discount_type,
                    'category': this.category,
                    'discount': this.discount,
                    'value': this.value,
                    'expiration': this.expiration,
                    'card_id': this.card_id,
                })
            });
            if (request.status === 200) {
                await getCards();
                this.sortCards();
                this.gift_cards = [];
                this.discount_codes = [];
                showMessage("Promo code updated!");
                await getCards();
                this.onReturn()
            }
        } else {
            if (this.value <= 0) {
                this.value_danger = true;
            }
            if (this.discount <= 0) {
                this.discount_danger = true;
            }
            if (!this.card_code) {
                this.code_danger = true;
            }
        }
    },
        onReturn(){
                this.selected = "";
                this.cur_card = null;
                this.discount_type = "";
                this.card_type = "";
                this.value_danger = false;
                this.discount_danger = false;
                this.code_danger = false;
        }
    },
    computed: {
        cards: function() {
            return cards.data.cards
        },
        categories: function(){
            return categories.data.categories.sort()
        }
    }

};