const editProductC = {
    props: [],
    template: `

<div id="selectProduct" v-if="!product_selected">
    <ul class="list-group">
    <label class="list-group-item" v-for="product in products.items" :style="{ background: [colors.settings_list]}" >
        <a href="#" class="nav-link" @click="getItemData(product.product_id)" :style="{color: [colors.settings_text]}">
          {{ product.product_name }}
        </a>
    </label>
    </ul>
</div>
<div id="editProduct" v-if="product_selected">
<form method = "POST" enctype = "multipart/form-data">
    <div class="form-group">
        <label :style="{ color: [colors.description]}">Title</label>
        <input class="form-control" id="new-product-title" v-model="title" placeholder="Enter product title">
        <p :style="{ color: [colors.danger_text]}" v-if="title_danger && title.length <= 0">Title is required</p>
    </div>
    <div class="custom-file form-group">
        <label class="form-label" for="customFile" :style="{ color: [colors.description]}">Image</label>
        <input type="file" class="form-control" id="customFile" name="file" @change="onFileChange" />
        <small class="form-text" :style="{ color: [colors.description]}">Preferably 400x500</small>
    </div>
    <div class="invalid-feedback">Example invalid custom file feedback</div>
    <div class="form-group">
        <label :style="{ color: [colors.description]}">Description</label>
        <textarea class="form-control" id="product-description" v-model="description" rows="3" placeholder="Enter product description"></textarea>
    </div>
    <div class="form-group">
    <label :style="{ color: [colors.description]}">Category</label>
    <select class="form-control m-0" v-model="category">
        <option v-for="(option, index) in categories" :value="option">{{option}}</option>
    </select>
    </div>
    <div class="form-group">
        <label :style="{ color: [colors.description]}">Price</label>
        <input class="form-control" type="number" v-model="price" id="new-product-price" placeholder="kr">
    </div>
    <div class="form-group" v-if="!item">
        <label :style="{ color: [colors.description]}">Duration</label>
        <input class="form-control" type="number" id="new-product-duration" v-model="duration" placeholder="min">
    </div>
    <div class="form-check form-check-inline form-group d-flex right-0">
      <label class="form-check-label" for="inlineCheckbox1" :style="{ color: [colors.description]}">Item</label>
      <input class="form-check-input mx-1" type="checkbox" :value="item" v-model="item" @click="durationReset()">
    </div>
</form>

    <div class="col p-2 border-3" :style="{ background: [colors.body] }">
        <div class="row my-5">
              <div class="col-md-9 mb-4 mx-auto">
                <div class="card h-100" :style="{ background: [colors.body]}">
                  <a v-if="image" href="#"><img class="card-img-top" :src="image" style="max-height: 500px; max-width: 400px" alt=""></a>
                  <a v-else href="#"><img class="card-img-top" :src="'/static/images/products/'+old_image+'.jpg'" style="max-height: 500px; max-width: 400px" alt=""></a>
                  <div class="card-body" :style="{ background: [colors.main_card_color]}">
                    <h4 class="card-title text-dark">
                      <a href="#" :style="{ color: [colors.title]}">{{ title }}</a>
                    </h4>
                    <p v-if="description.length<50" class="card-text" :style="{ color: [colors.description]}">{{ description }}</p>
                    <p v-else class="card-text" :style="{ color: [colors.description]}">{{ description.substring(0,50)+'..' }}</p>
                    <p class="d-flex justify-content-end" v-if="!item" :style="{ color: [colors.description]}"><small>Tid: {{ duration }}min</small></p>
                </div>
                  <div class="card-footer d-flex justify-content-between" :style="{ background: [colors.inner_footer]}">
                    <p class="my-auto" :style="{ color: [colors.title]}">kr{{ price }},-</p>
                    <button type="button" class="btn nav-link" :style="{ background: [colors.cart_button], color: [colors.cart_button_text]}" >
                        Add to cart
                    </button>
                  </div>
              </div>
            </div>
        </div>
</div>
<div class="modal-footer">
    <button type="button" class="btn" @click="onReturn()" :style="{ background: [colors.button_cancel], color: [colors.button_cancel_text]}">Cancel</button>
    <button type="button" class="btn" @click="uploadEdit()" :style="{ background: [colors.button_accept], color: [colors.button_accept_text]}">Save</button>
</div>
</div>
<!--<img :src="image" />-->

    `,
    data: function () {
        return {
            colors: color.data,
            products: product.data,
            product_selected: false,
            id: 0,
            title: "",
            description: "",
            price: 0,
            duration: 0,
            category: "",
            item: false,
            discount: 0,
            image: "",
            old_image: "",
            final_image: "",
            title_danger: false,
        }
    },
    created: async function() {
        await loadColors();
        this.colors = color.data;
    },
    methods: {
        // Retrieves every product in the database
        getItemData: async function(product_id) {
            let request = await fetch("/product/id/"+product_id, {
                method: 'GET',
            });
            if (request.status === 200) {
                let response = await request.json();
                this.id = response['product_id'];
                this.title = response['product_name'];
                this.description = response['product_description'];
                this.price = response['price'];
                this.duration = response['duration'];
                this.category = response['category'];
                this.discount = response['discount'];
                this.old_image = response['img_name'];
                this.final_image = response['img_name'];
                this.product_selected = true;
                this.item = !!response['is_item'];
            }
        },
        onReturn() {
            this.product_selected = false;
            this.id = 0;
            this.title = "";
            this.description = "";
            this.price = 0;
            this.duration = 0;
            this.item = false;
            this.image = "";
            this.old_image = "";
            this.final_image = "";
            this.title_danger = false;
        },
        // !taken from stack!
        // Creates a Base64 string from the uploaded image that gets converted to an image backend
        onFileChange(e) {
              var files = e.target.files || e.dataTransfer.files;
              if (!files.length)
                return;
              this.createImage(files[0]);
            },
        createImage(file) {
          var image = new Image();
          var reader = new FileReader();
          var vm = this;

          reader.onload = (e) => {
            vm.image = e.target.result;
          };
          reader.readAsDataURL(file);
        },
        // Applied changes on a product in the database
        uploadEdit: async function () {
            if (this.image) {
                this.final_image = this.image
            }
            if ((this.image || this.old_image) && this.title && isUser()) {
                let request = await fetch("/product", {
                    method: 'PUT',
                    headers: {"Content-Type": "application/json"},
                    body: JSON.stringify({ 'id': this.id,
                        'title': this.title, 'description': this.description, 'price': this.price,
                        'duration': this.duration, 'item': this.item, 'img': this.final_image,
                        'old_img': this.old_image, 'discount': this.discount, 'category': this.category
                    })
                });
                if (request.status === 200) {
                    await getProducts();
                    this.onReturn();
                    this.title_danger = false;
                    showMessage("Product updated!");
                    $('#editProductModal').modal('hide');
                    $('#editProductsModal').modal('show');
                }
            } else {
                this.title_danger = true;
            }
        },
        durationReset() {
            this.duration = 0
        }
    },
    computed: {
        categories: function() {
            return categories.data.categories.sort()
        },
    }
};

// Add the remaining features as in "addProducts"
// Add search function